# litestar-users

Effortlessly add secure authentication to your [Litestar](https://litestar.dev/) application.

## Features

- Session, JWT and JWTCookie authentication backends
- Customizable pre- and post-operation hooks
- Optional RBAC (Role based access control)
- Pre-configured route handlers for:
  - Authentication
  - Registration and verification
  - Password recovery
  - Administrative user and role management

## Getting started

### Installation

`pip install litestar-users`

### Documentation

[Read the documentation](https://lonelyvikingmichael.github.io/litestar-users/)

Otherwise [check out the examples](https://github.com/LonelyVikingMichael/litestar-users/tree/main/examples)
